@@ -84,7 +84,7 @@ class Domoticz(IPlugin):
 				log.msg("number  :  %s" % (int(rs['idx'])))
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 				jsonreq = resp.json()
-				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
+	#			log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
 					if int(rs['idx']) == int(rt['idx']):
 						log.msg("**************************  jsonreq - idx   :  %s" % (rt['idx']))
@@ -92,9 +92,9 @@ class Domoticz(IPlugin):
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
 #						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
 						log.msg("*********  jsonreq - Data   :  %s" % (rt['BatteryLevel']))
-						if location == "temperature" :
+						if entity == "dz_temperature" :
 							bodies = "la temperature a été trouvée et elle est de %s degré" % (rt['Temp'])
-						if location == "batterie" :
+						if entity == "dz_batterie" :
 							bodies = "le niveau de batterie a été trouvé et elle est de %s " % (rt['BatteryLevel'])
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
